from nginx import Nginx
import cli_file
import common
import fire
import json
import os
import re

class CLI(object):
    """PyToy CLI."""

    def path(self) -> str:
        """Get PyToy path."""
        return os.path.dirname(os.path.abspath(__file__))

    def version(self) -> str:
        """Get PyToy version."""
        path = common.find_file_by_pattern(
            os.path.dirname(self.path()) + "/pytoy-*.dist-info"
        )
        return re.findall(r"pytoy-(.*).dist-info", path)[0] if path else "0.0.0"

    class nginx(Nginx):
        pass

    def ls(
        self, dir: str = ".", max_depth: int | None = 1, indent: int | str | None = None
    ):
        """List directory."""
        return json.dumps(cli_file.list_file_structure(dir, max_depth), indent=indent)

    def replace_file(self, file: str, old: str, new: str, extension: str = None):
        if extension and not file.endswith(extension):
            return
        with open(file, "r") as f:
            text = f.read()
        text = text.replace(old, new)
        with open(file, "w") as f:
            f.write(text)

    def replace_dir(
        self,
        dir: str,
        old: str,
        new: str,
        extension: str = None,
        recursive: bool = False,
    ):
        for root, dirs, files in os.walk(dir):
            for file in files:
                file_path = os.path.join(root, file)
                self.replace_file(file_path, old, new, extension)

            if not recursive:
                break

            for subdir in dirs:
                subdir_path = os.path.join(root, subdir)
                self.replace_dir(subdir_path, old, new, extension, recursive)


def PyToy():
    fire.Fire(CLI)


if __name__ == "__main__":
    PyToy()



import os


def walk(dir, max_depth: int | None = 1):
    """Walk a directory up to a maximum depth."""
    if max_depth is None:
        return os.walk(dir)
    dir = os.path.abspath(dir)
    prefix_len = len(dir.split(os.sep))

    for root, dirs, files in os.walk(dir):
        depth = len(root.split(os.sep)) - prefix_len
        if depth < max_depth:
            yield root, dirs, files
        else:
            del dirs[:]


def list_file_structure(dir: str = ".", max_depth: int | None = 1):
    """List directory."""
    file_structure = {}

    for root, dirs, files in walk(dir, max_depth):
        for file in files:
            path = os.path.join(root, file)
            file_structure[path] = {
                "size": os.path.getsize(path),
                "last_modified": os.path.getmtime(path),
            }

    return file_structure



import glob
import os


def run_command_str(cmd: str):
    """Run a command as a string."""
    return os.popen(cmd).read().strip()


def find_file_by_pattern(pattern):
    """Find a file by pattern."""
    list_files = glob.glob(pattern)
    return list_files[0] if len(list_files) > 0 else None


from common import *


class Nginx:
    def installed(self) -> bool:
        """Check if Nginx is installed"""
        return bool(run_command_str("which nginx"))

    def version(self) -> str:
        """Get Nginx version"""
        return run_command_str("nginx -v")
    
    def log_error(self) -> str:
        """Get Nginx log"""
        return run_command_str("cat /var/log/nginx/error.log")
    
    def config(self) -> str:
        """Get Nginx config"""
        return run_command_str("nginx -T")
    
    def reload(self) -> str:
        """Reload Nginx"""
        return run_command_str("nginx -s reload")
    
    def restart(self) -> str:
        """Restart Nginx"""
        return run_command_str("nginx -s reopen")
